Class: Aws::CostExplorer::Types::CostAndUsageComparison
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::CostAndUsageComparison
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Represents a comparison of cost and usage metrics between two time periods.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cost_and_usage_selector ⇒ Types::Expression
Use
Expressionto filter in various Cost Explorer APIs. -
#metrics ⇒ Hash<String,Types::ComparisonMetricValue>
A mapping of metric names to their comparison values.
Instance Attribute Details
#cost_and_usage_selector ⇒ Types::Expression
Use Expression to filter in various Cost Explorer APIs.
Not all Expression types are supported in each API. Refer to the documentation for each specific API to see what is supported.
There are two patterns:
-
Simple dimension values.
-
There are three types of simple dimension values:
CostCategories,Tags, andDimensions.-
Specify the
CostCategoriesfield to define a filter that acts on Cost Categories. -
Specify the
Tagsfield to define a filter that acts on Cost Allocation Tags. -
Specify the
Dimensionsfield to define a filter that acts on the [DimensionValues][1].
-
-
For each filter type, you can set the dimension name and values for the filters that you plan to use.
-
For example, you can filter for ‘REGION==us-east-1 OR REGION==us-west-1`. For
GetRightsizingRecommendation, the Region is a full name (for example, `REGION==US East (N. Virginia)`. -
The corresponding
Expressionfor this example is as follows: ‘{ “Dimensions”: { “Key”: “REGION”, “Values”: [ “us-east-1”, “us-west-1” ] } }` -
As shown in the previous example, lists of dimension values are combined with
ORwhen applying the filter.
-
-
You can also set different match options to further control how the filter behaves. Not all APIs support match options. Refer to the documentation for each specific API to see what is supported.
-
For example, you can filter for linked account names that start with “a”.
-
The corresponding
Expressionfor this example is as follows: ‘{ “Dimensions”: { “Key”: “LINKED_ACCOUNT_NAME”, “MatchOptions”: [ “STARTS_WITH” ], “Values”: [ “a” ] } }`
-
-
-
Compound
Expressiontypes with logical operations.-
You can use multiple
Expressiontypes and the logical operatorsAND/OR/NOTto create a list of one or moreExpressionobjects. By doing this, you can filter by more advanced options. -
For example, you can filter by ‘((REGION == us-east-1 OR REGION
us-west-1) OR (TAG.Type == Type1)) AND (USAGE_TYPE !=
DataTransfer)‘.
-
The corresponding
Expressionfor this example is as follows: ‘{ “And”: [ [ {“Dimensions”: { “Key”: “REGION”, “Values”:- “us-east-1”, “us-west-1”
-
}, {“Tags”: { “Key”: “TagName”,
“Values”: [“Value1”] } } ]}, {“Dimensions”: { “Key”: “USAGE_TYPE”, “Values”: [“DataTransfer”] }} ] } ‘
<note markdown=“1”> Because each
Expressioncan have only one operator, the service returns an error if more than one is specified. The following example shows anExpressionobject that creates an error: ‘ { “And”: [ … ], “Dimensions”: { “Key”: “USAGE_TYPE”, “Values”: [ “DataTransfer” ] } } `The following is an example of the corresponding error message:‘“Expression has more than one roots. Only one root operator is allowed for each expression: And, Or, Not, Dimensions, Tags, CostCategories”`
</note> -
<note markdown=“1”> For the GetRightsizingRecommendation action, a combination of OR and NOT isn’t supported. OR isn’t supported between different dimensions, or dimensions and tags. NOT operators aren’t supported. Dimensions are also limited to LINKED_ACCOUNT, REGION, or RIGHTSIZING_TYPE.
For the `GetReservationPurchaseRecommendation` action, only NOT is
supported. AND and OR aren’t supported. Dimensions are limited to LINKED_ACCOUNT.
</note>
[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DimensionValues.html
708 709 710 711 712 713 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 708 class CostAndUsageComparison < Struct.new( :cost_and_usage_selector, :metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Hash<String,Types::ComparisonMetricValue>
A mapping of metric names to their comparison values.
708 709 710 711 712 713 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 708 class CostAndUsageComparison < Struct.new( :cost_and_usage_selector, :metrics) SENSITIVE = [] include Aws::Structure end |