Class: Aws::CostExplorer::Types::CostCategoryInheritedValueDimension
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::CostCategoryInheritedValueDimension
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
When you create or update a cost category, you can define the CostCategoryRule rule type as INHERITED_VALUE. This rule type adds the flexibility to define a rule that dynamically inherits the cost category value from the dimension value that’s defined by CostCategoryInheritedValueDimension. For example, suppose that you want to dynamically group costs that are based on the value of a specific tag key. First, choose an inherited value rule type, and then choose the tag dimension and specify the tag key to use.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimension_key ⇒ String
The key to extract cost category values.
-
#dimension_name ⇒ String
The name of the dimension that’s used to group costs.
Instance Attribute Details
#dimension_key ⇒ String
The key to extract cost category values.
797 798 799 800 801 802 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 797 class CostCategoryInheritedValueDimension < Struct.new( :dimension_name, :dimension_key) SENSITIVE = [] include Aws::Structure end |
#dimension_name ⇒ String
The name of the dimension that’s used to group costs.
If you specify LINKED_ACCOUNT_NAME, the cost category value is based on account name. If you specify TAG, the cost category value is based on the value of the specified tag key.
797 798 799 800 801 802 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 797 class CostCategoryInheritedValueDimension < Struct.new( :dimension_name, :dimension_key) SENSITIVE = [] include Aws::Structure end |