Class: Aws::CostExplorer::Types::CostCategoryValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::CostCategoryValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
The Cost Categories values used for filtering the costs.
If Values and Key are not specified, the ABSENT MatchOption is applied to all Cost Categories. That is, it filters on resources that aren’t mapped to any Cost Categories.
If Values is provided and Key isn’t specified, the ABSENT MatchOption is applied to the Cost Categories Key only. That is, it filters on resources without the given Cost Categories key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The unique name of the cost category.
-
#match_options ⇒ Array<String>
The match options that you can use to filter your results.
-
#values ⇒ Array<String>
The specific value of the cost category.
Instance Attribute Details
#key ⇒ String
The unique name of the cost category.
1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 1053 class CostCategoryValues < Struct.new( :key, :values, :match_options) SENSITIVE = [] include Aws::Structure end |
#match_options ⇒ Array<String>
The match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is EQUALS and CASE_SENSITIVE.
1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 1053 class CostCategoryValues < Struct.new( :key, :values, :match_options) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The specific value of the cost category.
1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 1053 class CostCategoryValues < Struct.new( :key, :values, :match_options) SENSITIVE = [] include Aws::Structure end |