Class: Aws::CostExplorer::Types::EC2ResourceDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Details on the Amazon EC2 Resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hourly_on_demand_rateString

The hourly public On-Demand rate for the instance type.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of Amazon Web Services instance.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#memoryString

The memory capacity of the Amazon Web Services instance.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#network_performanceString

The network performance capacity of the Amazon Web Services instance.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The platform of the Amazon Web Services instance. The platform is the specific combination of operating system, license model, and software on an instance.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region of the instance.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#skuString

The SKU of the product.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#storageString

The disk storage of the Amazon Web Services instance. This doesn't include EBS storage.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end

#vcpuString

The number of VCPU cores in the Amazon Web Services instance type.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/aws-sdk-costexplorer/types.rb', line 2018

class EC2ResourceDetails < Struct.new(
  :hourly_on_demand_rate,
  :instance_type,
  :platform,
  :region,
  :sku,
  :memory,
  :network_performance,
  :storage,
  :vcpu)
  SENSITIVE = []
  include Aws::Structure
end