Class: Aws::CostExplorer::Types::ElastiCacheInstanceDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Details about the Amazon ElastiCache reservations that Amazon Web Services recommends that you purchase.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_generationBoolean

Determines whether the recommendation is for a current generation instance.



2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/aws-sdk-costexplorer/types.rb', line 2157

class ElastiCacheInstanceDetails < Struct.new(
  :family,
  :node_type,
  :region,
  :product_description,
  :current_generation,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#familyString

The instance family of the recommended reservation.



2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/aws-sdk-costexplorer/types.rb', line 2157

class ElastiCacheInstanceDetails < Struct.new(
  :family,
  :node_type,
  :region,
  :product_description,
  :current_generation,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#node_typeString

The type of node that Amazon Web Services recommends.



2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/aws-sdk-costexplorer/types.rb', line 2157

class ElastiCacheInstanceDetails < Struct.new(
  :family,
  :node_type,
  :region,
  :product_description,
  :current_generation,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#product_descriptionString

The description of the recommended reservation.



2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/aws-sdk-costexplorer/types.rb', line 2157

class ElastiCacheInstanceDetails < Struct.new(
  :family,
  :node_type,
  :region,
  :product_description,
  :current_generation,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region of the recommended reservation.



2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/aws-sdk-costexplorer/types.rb', line 2157

class ElastiCacheInstanceDetails < Struct.new(
  :family,
  :node_type,
  :region,
  :product_description,
  :current_generation,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end

#size_flex_eligibleBoolean

Determines whether the recommended reservation is size flexible.



2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/aws-sdk-costexplorer/types.rb', line 2157

class ElastiCacheInstanceDetails < Struct.new(
  :family,
  :node_type,
  :region,
  :product_description,
  :current_generation,
  :size_flex_eligible)
  SENSITIVE = []
  include Aws::Structure
end