Class: Aws::CostExplorer::Types::GetAnomaliesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#date_intervalTypes::AnomalyDateInterval

Assigns the start and end dates for retrieving cost anomalies. The returned anomaly object will have an AnomalyEndDate in the specified time range.



2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
# File 'lib/aws-sdk-costexplorer/types.rb', line 2406

class GetAnomaliesRequest < Struct.new(
  :monitor_arn,
  :date_interval,
  :feedback,
  :total_impact,
  :next_page_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#feedbackString

Filters anomaly results by the feedback field on the anomaly object.

Returns:

  • (String)


2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
# File 'lib/aws-sdk-costexplorer/types.rb', line 2406

class GetAnomaliesRequest < Struct.new(
  :monitor_arn,
  :date_interval,
  :feedback,
  :total_impact,
  :next_page_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The number of entries a paginated response contains.

Returns:

  • (Integer)


2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
# File 'lib/aws-sdk-costexplorer/types.rb', line 2406

class GetAnomaliesRequest < Struct.new(
  :monitor_arn,
  :date_interval,
  :feedback,
  :total_impact,
  :next_page_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_arnString

Retrieves all of the cost anomalies detected for a specific cost anomaly monitor Amazon Resource Name (ARN).

Returns:

  • (String)


2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
# File 'lib/aws-sdk-costexplorer/types.rb', line 2406

class GetAnomaliesRequest < Struct.new(
  :monitor_arn,
  :date_interval,
  :feedback,
  :total_impact,
  :next_page_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_tokenString

The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.

Returns:

  • (String)


2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
# File 'lib/aws-sdk-costexplorer/types.rb', line 2406

class GetAnomaliesRequest < Struct.new(
  :monitor_arn,
  :date_interval,
  :feedback,
  :total_impact,
  :next_page_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#total_impactTypes::TotalImpactFilter

Filters anomaly results by the total impact field on the anomaly object. For example, you can filter anomalies ‘GREATER_THAN 200.00` to retrieve anomalies, with an estimated dollar impact greater than 200.



2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
# File 'lib/aws-sdk-costexplorer/types.rb', line 2406

class GetAnomaliesRequest < Struct.new(
  :monitor_arn,
  :date_interval,
  :feedback,
  :total_impact,
  :next_page_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end