Class: Aws::CostExplorer::Types::GetCostCategoriesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetCostCategoriesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cost_category_names ⇒ Array<String>
The names of the cost categories.
-
#cost_category_values ⇒ Array<String>
The cost category values.
-
#next_page_token ⇒ String
If the number of objects that are still available for retrieval exceeds the quota, Amazon Web Services returns a NextPageToken value in the response.
-
#return_size ⇒ Integer
The number of objects that are returned.
-
#total_size ⇒ Integer
The total number of objects.
Instance Attribute Details
#cost_category_names ⇒ Array<String>
The names of the cost categories.
3288 3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3288 class GetCostCategoriesResponse < Struct.new( :next_page_token, :cost_category_names, :cost_category_values, :return_size, :total_size) SENSITIVE = [] include Aws::Structure end |
#cost_category_values ⇒ Array<String>
The cost category values.
If the CostCategoryName key isn’t specified in the request, the CostCategoryValues fields aren’t returned.
3288 3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3288 class GetCostCategoriesResponse < Struct.new( :next_page_token, :cost_category_names, :cost_category_values, :return_size, :total_size) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
If the number of objects that are still available for retrieval exceeds the quota, Amazon Web Services returns a NextPageToken value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.
3288 3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3288 class GetCostCategoriesResponse < Struct.new( :next_page_token, :cost_category_names, :cost_category_values, :return_size, :total_size) SENSITIVE = [] include Aws::Structure end |
#return_size ⇒ Integer
The number of objects that are returned.
3288 3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3288 class GetCostCategoriesResponse < Struct.new( :next_page_token, :cost_category_names, :cost_category_values, :return_size, :total_size) SENSITIVE = [] include Aws::Structure end |
#total_size ⇒ Integer
The total number of objects.
3288 3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3288 class GetCostCategoriesResponse < Struct.new( :next_page_token, :cost_category_names, :cost_category_values, :return_size, :total_size) SENSITIVE = [] include Aws::Structure end |