Class: Aws::CostExplorer::Types::GetCostForecastRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetCostForecastRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_view_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies a specific billing view.
-
#filter ⇒ Types::Expression
The filters that you want to use to filter your forecast.
-
#granularity ⇒ String
How granular you want the forecast to be.
-
#metric ⇒ String
Which metric Cost Explorer uses to create your forecast.
-
#prediction_interval_level ⇒ Integer
Cost Explorer always returns the mean forecast as a single point.
-
#time_period ⇒ Types::DateInterval
The period of time that you want the forecast to cover.
Instance Attribute Details
#billing_view_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies a specific billing view. The ARN is used to specify which particular billing view you want to interact with or retrieve information from when making API calls related to Amazon Web Services Billing and Cost Management features. The BillingViewArn can be retrieved by calling the ListBillingViews API.
3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3574 class GetCostForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::Expression
The filters that you want to use to filter your forecast. The GetCostForecast API supports filtering by the following dimensions:
-
AZ -
INSTANCE_TYPE -
LINKED_ACCOUNT -
OPERATION -
PURCHASE_TYPE -
REGION -
SERVICE -
USAGE_TYPE -
USAGE_TYPE_GROUP -
RECORD_TYPE -
OPERATING_SYSTEM -
TENANCY -
SCOPE -
PLATFORM -
SUBSCRIPTION_ID -
LEGAL_ENTITY_NAME -
DEPLOYMENT_OPTION -
DATABASE_ENGINE -
INSTANCE_TYPE_FAMILY -
BILLING_ENTITY -
RESERVATION_ID -
SAVINGS_PLAN_ARN
3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3574 class GetCostForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#granularity ⇒ String
How granular you want the forecast to be. You can get 3 months of DAILY forecasts or 18 months of MONTHLY forecasts.
The GetCostForecast operation supports only DAILY and MONTHLY granularities.
3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3574 class GetCostForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ String
Which metric Cost Explorer uses to create your forecast. For more information about blended and unblended rates, see [Why does the “blended” annotation appear on some line items in my bill?].
Valid values for a GetCostForecast call are the following:
-
AMORTIZED_COST
-
BLENDED_COST
-
NET_AMORTIZED_COST
-
NET_UNBLENDED_COST
-
UNBLENDED_COST
[1]: aws.amazon.com/premiumsupport/knowledge-center/blended-rates-intro/
3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3574 class GetCostForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#prediction_interval_level ⇒ Integer
Cost Explorer always returns the mean forecast as a single point. You can request a prediction interval around the mean by specifying a confidence level. The higher the confidence level, the more confident Cost Explorer is about the actual value falling in the prediction interval. Higher confidence levels result in wider prediction intervals.
3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3574 class GetCostForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::DateInterval
The period of time that you want the forecast to cover. The start date must be equal to or no later than the current date to avoid a validation error.
3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3574 class GetCostForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |