Class: Aws::CostExplorer::Types::GetCostForecastResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetCostForecastResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#forecast_results_by_time ⇒ Array<Types::ForecastResult>
The forecasts for your query, in order.
-
#total ⇒ Types::MetricValue
How much you are forecasted to spend over the forecast period, in
USD.
Instance Attribute Details
#forecast_results_by_time ⇒ Array<Types::ForecastResult>
The forecasts for your query, in order. For DAILY forecasts, this is a list of days. For MONTHLY forecasts, this is a list of months.
3598 3599 3600 3601 3602 3603 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3598 class GetCostForecastResponse < Struct.new( :total, :forecast_results_by_time) SENSITIVE = [] include Aws::Structure end |
#total ⇒ Types::MetricValue
How much you are forecasted to spend over the forecast period, in USD.
3598 3599 3600 3601 3602 3603 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 3598 class GetCostForecastResponse < Struct.new( :total, :forecast_results_by_time) SENSITIVE = [] include Aws::Structure end |