Class: Aws::CostExplorer::Types::GetReservationPurchaseRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetReservationPurchaseRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID that's associated with the recommendation.
-
#account_scope ⇒ String
The account scope that you want your recommendations for.
-
#filter ⇒ Types::Expression
Use
Expressionto filter in various Cost Explorer APIs. -
#lookback_period_in_days ⇒ String
The number of previous days that you want Amazon Web Services to consider when it calculates your recommendations.
-
#next_page_token ⇒ String
The pagination token that indicates the next set of results that you want to retrieve.
-
#page_size ⇒ Integer
The number of recommendations that you want returned in a single response object.
-
#payment_option ⇒ String
The reservation purchase option that you want recommendations for.
-
#service ⇒ String
The specific service that you want recommendations for.
-
#service_specification ⇒ Types::ServiceSpecification
The hardware specifications for the service instances that you want recommendations for, such as standard or convertible Amazon EC2 instances.
-
#term_in_years ⇒ String
The reservation term that you want recommendations for.
Instance Attribute Details
#account_id ⇒ String
The account ID that's associated with the recommendation.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#account_scope ⇒ String
The account scope that you want your recommendations for. Amazon Web
Services calculates recommendations including the management account
and member accounts if the value is set to PAYER. If the value is
LINKED, recommendations are calculated for individual member
accounts only.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::Expression
Use Expression to filter in various Cost Explorer APIs.
Not all Expression types are supported in each API. Refer to the
documentation for each specific API to see what is supported.
There are two patterns:
-
Simple dimension values.
-
There are three types of simple dimension values:
CostCategories,Tags, andDimensions.-
Specify the
CostCategoriesfield to define a filter that acts on Cost Categories. -
Specify the
Tagsfield to define a filter that acts on Cost Allocation Tags. -
Specify the
Dimensionsfield to define a filter that acts on theDimensionValues.
-
-
For each filter type, you can set the dimension name and values for the filters that you plan to use.
-
For example, you can filter for
REGION==us-east-1 OR REGION==us-west-1. ForGetRightsizingRecommendation, the Region is a full name (for example,REGION==US East (N. Virginia). -
The corresponding
Expressionfor this example is as follows:{ "Dimensions": { "Key": "REGION", "Values": [ "us-east-1", "us-west-1" ] } } -
As shown in the previous example, lists of dimension values are combined with
ORwhen applying the filter.
-
-
You can also set different match options to further control how the filter behaves. Not all APIs support match options. Refer to the documentation for each specific API to see what is supported.
-
For example, you can filter for linked account names that start with "a".
-
The corresponding
Expressionfor this example is as follows:{ "Dimensions": { "Key": "LINKED_ACCOUNT_NAME", "MatchOptions": [ "STARTS_WITH" ], "Values": [ "a" ] } }
-
-
Compound
Expressiontypes with logical operations. -
You can use multiple
Expressiontypes and the logical operatorsAND/OR/NOTto create a list of one or moreExpressionobjects. By doing this, you can filter by more advanced options. -
For example, you can filter by `((REGION == us-east-1 OR REGION
us-west-1) OR (TAG.Type == Type1)) AND (USAGE_TYPE !=
DataTransfer)`.
-
The corresponding
Expressionfor this example is as follows:{ "And": [ {"Or": [ {"Dimensions": { "Key": "REGION", "Values": [ "us-east-1", "us-west-1" ] }}, {"Tags": { "Key": "TagName", "Values": ["Value1"] } } ]}, {"Not": {"Dimensions": { "Key": "USAGE_TYPE", "Values": ["DataTransfer"] }}} ] }Because each Expressioncan have only one operator, the service returns an error if more than one is specified. The following example shows anExpressionobject that creates an error:{ "And": [ ... ], "Dimensions": { "Key": "USAGE_TYPE", "Values": [ "DataTransfer" ] } }
The following is an example of the corresponding error message:
`"Expression has more than one roots. Only one root operator is
allowed for each expression: And, Or, Not, Dimensions, Tags,
CostCategories"`
GetRightsizingRecommendation action, a combination of OR
and NOT isn't supported. OR isn't supported between different
dimensions, or dimensions and tags. NOT operators aren't supported.
Dimensions are also limited to LINKED_ACCOUNT, REGION, or
RIGHTSIZING_TYPE.
For the GetReservationPurchaseRecommendation action, only NOT is
supported. AND and OR aren't supported. Dimensions are limited to
LINKED_ACCOUNT.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#lookback_period_in_days ⇒ String
The number of previous days that you want Amazon Web Services to consider when it calculates your recommendations.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The pagination token that indicates the next set of results that you want to retrieve.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of recommendations that you want returned in a single response object.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The reservation purchase option that you want recommendations for.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The specific service that you want recommendations for.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#service_specification ⇒ Types::ServiceSpecification
The hardware specifications for the service instances that you want recommendations for, such as standard or convertible Amazon EC2 instances.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#term_in_years ⇒ String
The reservation term that you want recommendations for.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4390 class GetReservationPurchaseRecommendationRequest < Struct.new( :account_id, :service, :filter, :account_scope, :lookback_period_in_days, :term_in_years, :payment_option, :service_specification, :page_size, :next_page_token) SENSITIVE = [] include Aws::Structure end |