Class: Aws::CostExplorer::Types::GetReservationUtilizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetReservationUtilizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::Expression
Filters utilization data by dimensions.
-
#granularity ⇒ String
If
GroupByis set,Granularitycan't be set. -
#group_by ⇒ Array<Types::GroupDefinition>
Groups only by
SUBSCRIPTION_ID. -
#max_results ⇒ Integer
The maximum number of objects that you returned for this request.
-
#next_page_token ⇒ String
The token to retrieve the next set of results.
-
#sort_by ⇒ Types::SortDefinition
The value that you want to sort the data by.
-
#time_period ⇒ Types::DateInterval
Sets the start and end dates for retrieving Reserved Instance (RI) utilization.
Instance Attribute Details
#filter ⇒ Types::Expression
Filters utilization data by dimensions. You can filter by the following dimensions:
-
AZ
-
CACHE_ENGINE
-
DEPLOYMENT_OPTION
-
INSTANCE_TYPE
-
LINKED_ACCOUNT
-
OPERATING_SYSTEM
-
PLATFORM
-
REGION
-
SERVICE
If not specified, the SERVICEfilter defaults to Amazon Elastic Compute Cloud - Compute. Supported values forSERVICEare Amazon Elastic Compute Cloud - Compute, Amazon Relational Database Service, Amazon ElastiCache, Amazon Redshift, and Amazon Elasticsearch Service. The value for theSERVICEfilter should not exceed "1". -
SCOPE
-
TENANCY
GetReservationUtilization uses the same Expression object as
the other operations, but only AND is supported among each
dimension, and nesting is supported up to only one level deep. If
there are multiple values for a dimension, they are OR'd together.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4554 class GetReservationUtilizationRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :sort_by, :next_page_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#granularity ⇒ String
If GroupBy is set, Granularity can't be set. If Granularity
isn't set, the response object doesn't include Granularity,
either MONTHLY or DAILY. If both GroupBy and Granularity
aren't set, GetReservationUtilization defaults to DAILY.
The GetReservationUtilization operation supports only DAILY and
MONTHLY granularities.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4554 class GetReservationUtilizationRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :sort_by, :next_page_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<Types::GroupDefinition>
Groups only by SUBSCRIPTION_ID. Metadata is included.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4554 class GetReservationUtilizationRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :sort_by, :next_page_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of objects that you returned for this request. If more objects are available, in the response, Amazon Web Services provides a NextPageToken value that you can use in a subsequent call to get the next batch of objects.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4554 class GetReservationUtilizationRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :sort_by, :next_page_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4554 class GetReservationUtilizationRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :sort_by, :next_page_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ Types::SortDefinition
The value that you want to sort the data by.
The following values are supported for Key:
-
UtilizationPercentage -
UtilizationPercentageInUnits -
PurchasedHours -
PurchasedUnits -
TotalActualHours -
TotalActualUnits -
UnusedHours -
UnusedUnits -
OnDemandCostOfRIHoursUsed -
NetRISavings -
TotalPotentialRISavings -
AmortizedUpfrontFee -
AmortizedRecurringFee -
TotalAmortizedFee -
RICostForUnusedHours -
RealizedSavings -
UnrealizedSavings
The supported values for SortOrder are ASCENDING and
DESCENDING.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4554 class GetReservationUtilizationRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :sort_by, :next_page_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::DateInterval
Sets the start and end dates for retrieving Reserved Instance (RI)
utilization. The start date is inclusive, but the end date is
exclusive. For example, if start is 2017-01-01 and end is
2017-05-01, then the cost and usage data is retrieved from
2017-01-01 up to and including 2017-04-30 but not including
2017-05-01.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4554 class GetReservationUtilizationRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :sort_by, :next_page_token, :max_results) SENSITIVE = [] include Aws::Structure end |