Class: Aws::CostExplorer::Types::GetSavingsPlansUtilizationDetailsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetSavingsPlansUtilizationDetailsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_type ⇒ Array<String>
The data type.
-
#filter ⇒ Types::Expression
Filters Savings Plans utilization coverage data for active Savings Plans dimensions.
-
#max_results ⇒ Integer
The number of items to be returned in a response.
-
#next_token ⇒ String
The token to retrieve the next set of results.
-
#sort_by ⇒ Types::SortDefinition
The value that you want to sort the data by.
-
#time_period ⇒ Types::DateInterval
The time period that you want the usage and costs for.
Instance Attribute Details
#data_type ⇒ Array<String>
The data type.
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5064 class GetSavingsPlansUtilizationDetailsRequest < Struct.new( :time_period, :filter, :data_type, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::Expression
Filters Savings Plans utilization coverage data for active Savings Plans dimensions. You can filter data with the following dimensions:
-
LINKED_ACCOUNT -
SAVINGS_PLAN_ARN -
REGION -
PAYMENT_OPTION -
INSTANCE_TYPE_FAMILY
GetSavingsPlansUtilizationDetails uses the same [Expression] object as the other operations, but only AND is supported among each dimension.
[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_Expression.html
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5064 class GetSavingsPlansUtilizationDetailsRequest < Struct.new( :time_period, :filter, :data_type, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The number of items to be returned in a response. The default is 20, with a minimum value of 1.
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5064 class GetSavingsPlansUtilizationDetailsRequest < Struct.new( :time_period, :filter, :data_type, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5064 class GetSavingsPlansUtilizationDetailsRequest < Struct.new( :time_period, :filter, :data_type, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ Types::SortDefinition
The value that you want to sort the data by.
The following values are supported for Key:
-
UtilizationPercentage -
TotalCommitment -
UsedCommitment -
UnusedCommitment -
NetSavings -
AmortizedRecurringCommitment -
AmortizedUpfrontCommitment
The supported values for SortOrder are ASCENDING and DESCENDING.
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5064 class GetSavingsPlansUtilizationDetailsRequest < Struct.new( :time_period, :filter, :data_type, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::DateInterval
The time period that you want the usage and costs for. The Start date must be within 13 months. The End date must be after the Start date, and before the current date. Future dates can’t be used as an End date.
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5064 class GetSavingsPlansUtilizationDetailsRequest < Struct.new( :time_period, :filter, :data_type, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |