Class: Aws::CostExplorer::Types::GetSavingsPlansUtilizationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::Expression

Filters Savings Plans utilization coverage data for active Savings Plans dimensions. You can filter data with the following dimensions:

  • LINKED_ACCOUNT

  • SAVINGS_PLAN_ARN

  • SAVINGS_PLANS_TYPE

  • REGION

  • PAYMENT_OPTION

  • INSTANCE_TYPE_FAMILY

GetSavingsPlansUtilization uses the same [Expression] object as the other operations, but only AND is supported among each dimension.

[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_Expression.html

Returns:



5166
5167
5168
5169
5170
5171
5172
5173
# File 'lib/aws-sdk-costexplorer/types.rb', line 5166

class GetSavingsPlansUtilizationRequest < Struct.new(
  :time_period,
  :granularity,
  :filter,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#granularityString

The granularity of the Amazon Web Services utillization data for your Savings Plans.

The GetSavingsPlansUtilization operation supports only DAILY and MONTHLY granularities.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
# File 'lib/aws-sdk-costexplorer/types.rb', line 5166

class GetSavingsPlansUtilizationRequest < Struct.new(
  :time_period,
  :granularity,
  :filter,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byTypes::SortDefinition

The value that you want to sort the data by.

The following values are supported for Key:

  • UtilizationPercentage

  • TotalCommitment

  • UsedCommitment

  • UnusedCommitment

  • NetSavings

The supported values for SortOrder are ASCENDING and DESCENDING.



5166
5167
5168
5169
5170
5171
5172
5173
# File 'lib/aws-sdk-costexplorer/types.rb', line 5166

class GetSavingsPlansUtilizationRequest < Struct.new(
  :time_period,
  :granularity,
  :filter,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#time_periodTypes::DateInterval

The time period that you want the usage and costs for. The Start date must be within 13 months. The End date must be after the Start date, and before the current date. Future dates can’t be used as an End date.

Returns:



5166
5167
5168
5169
5170
5171
5172
5173
# File 'lib/aws-sdk-costexplorer/types.rb', line 5166

class GetSavingsPlansUtilizationRequest < Struct.new(
  :time_period,
  :granularity,
  :filter,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end