Class: Aws::CostExplorer::Types::GetTagsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_view_arnString

The Amazon Resource Name (ARN) that uniquely identifies a specific billing view. The ARN is used to specify which particular billing view you want to interact with or retrieve information from when making API calls related to Amazon Web Services Billing and Cost Management features. The BillingViewArn can be retrieved by calling the ListBillingViews API.

Returns:

  • (String)


5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#filterTypes::Expression

Use ‘Expression` to filter in various Cost Explorer APIs.

Not all ‘Expression` types are supported in each API. Refer to the documentation for each specific API to see what is supported.

There are two patterns:

  • Simple dimension values.

    • There are three types of simple dimension values: ‘CostCategories`, `Tags`, and `Dimensions`.

      • Specify the ‘CostCategories` field to define a filter that acts on Cost Categories.

      • Specify the ‘Tags` field to define a filter that acts on Cost Allocation Tags.

      • Specify the ‘Dimensions` field to define a filter that acts on the [ `DimensionValues` ][1].

    • For each filter type, you can set the dimension name and values for the filters that you plan to use.

      • For example, you can filter for ‘REGION==us-east-1 OR REGION==us-west-1`. For `GetRightsizingRecommendation`, the Region is a full name (for example, `REGION==US East (N. Virginia)`.

      • The corresponding ‘Expression` for this example is as follows: `{ “Dimensions”: { “Key”: “REGION”, “Values”: [ “us-east-1”, “us-west-1” ] } }`

      • As shown in the previous example, lists of dimension values are combined with ‘OR` when applying the filter.

    • You can also set different match options to further control how the filter behaves. Not all APIs support match options. Refer to the documentation for each specific API to see what is supported.

      • For example, you can filter for linked account names that start with “a”.

      • The corresponding ‘Expression` for this example is as follows: `{ “Dimensions”: { “Key”: “LINKED_ACCOUNT_NAME”, “MatchOptions”: [ “STARTS_WITH” ], “Values”: [ “a” ] } }`

  • Compound ‘Expression` types with logical operations.

    • You can use multiple ‘Expression` types and the logical operators `AND/OR/NOT` to create a list of one or more `Expression` objects. By doing this, you can filter by more advanced options.

    • For example, you can filter by ‘((REGION == us-east-1 OR REGION

      us-west-1) OR (TAG.Type == Type1)) AND (USAGE_TYPE !=

      DataTransfer)‘.

    • The corresponding ‘Expression` for this example is as follows: `{ “And”: [ [ {“Dimensions”: { “Key”: “REGION”, “Values”:

      “us-east-1”, “us-west-1”

      }, {“Tags”: { “Key”: “TagName”,

      “Values”: [“Value1”] } } ]}, {“Dimensions”: { “Key”: “USAGE_TYPE”, “Values”: [“DataTransfer”] }} ] } ‘

    <note markdown=“1”> Because each ‘Expression` can have only one operator, the service returns an error if more than one is specified. The following example shows an `Expression` object that creates an error: ` { “And”: [ … ], “Dimensions”: { “Key”: “USAGE_TYPE”, “Values”: [ “DataTransfer” ] } } `

    The following is an example of the corresponding error message:
    

    ‘“Expression has more than one roots. Only one root operator is allowed for each expression: And, Or, Not, Dimensions, Tags, CostCategories”`

    </note>
    

<note markdown=“1”> For the ‘GetRightsizingRecommendation` action, a combination of OR and NOT isn’t supported. OR isn’t supported between different dimensions, or dimensions and tags. NOT operators aren’t supported. Dimensions are also limited to ‘LINKED_ACCOUNT`, `REGION`, or `RIGHTSIZING_TYPE`.

For the `GetReservationPurchaseRecommendation` action, only NOT is

supported. AND and OR aren’t supported. Dimensions are limited to ‘LINKED_ACCOUNT`.

</note>

[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DimensionValues.html

Returns:



5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

This field is only used when SortBy is provided in the request. The maximum number of objects that are returned for this request. If MaxResults isn’t specified with SortBy, the request returns 1000 results as the default value for this parameter.

For ‘GetTags`, MaxResults has an upper quota of 1000.

Returns:

  • (Integer)


5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_tokenString

The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.

Returns:

  • (String)


5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#search_stringString

The value that you want to search for.

Returns:

  • (String)


5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byArray<Types::SortDefinition>

The value that you want to sort the data by.

The key represents cost and usage metrics. The following values are supported:

  • ‘BlendedCost`

  • ‘UnblendedCost`

  • ‘AmortizedCost`

  • ‘NetAmortizedCost`

  • ‘NetUnblendedCost`

  • ‘UsageQuantity`

  • ‘NormalizedUsageAmount`

The supported values for ‘SortOrder` are `ASCENDING` and `DESCENDING`.

When you use ‘SortBy`, `NextPageToken` and `SearchString` aren’t supported.

Returns:



5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keyString

The key of the tag that you want to return values for.

Returns:

  • (String)


5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#time_periodTypes::DateInterval

The start and end dates for retrieving the dimension values. The start date is inclusive, but the end date is exclusive. For example, if ‘start` is `2017-01-01` and `end` is `2017-05-01`, then the cost and usage data is retrieved from `2017-01-01` up to and including `2017-04-30` but not including `2017-05-01`.

Returns:



5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
# File 'lib/aws-sdk-costexplorer/types.rb', line 5355

class GetTagsRequest < Struct.new(
  :search_string,
  :time_period,
  :tag_key,
  :filter,
  :sort_by,
  :billing_view_arn,
  :max_results,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end