Class: Aws::CostExplorer::Types::ListCostAllocationTagsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of objects that are returned for this request. By default, the request returns 100 results.

Returns:

  • (Integer)


5797
5798
5799
5800
5801
5802
5803
5804
5805
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797

class ListCostAllocationTagsRequest < Struct.new(
  :status,
  :tag_keys,
  :type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.

Returns:

  • (String)


5797
5798
5799
5800
5801
5802
5803
5804
5805
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797

class ListCostAllocationTagsRequest < Struct.new(
  :status,
  :tag_keys,
  :type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of cost allocation tag keys that are returned for this request.

Returns:

  • (String)


5797
5798
5799
5800
5801
5802
5803
5804
5805
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797

class ListCostAllocationTagsRequest < Struct.new(
  :status,
  :tag_keys,
  :type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keysArray<String>

The list of cost allocation tag keys that are returned for this request.

Returns:

  • (Array<String>)


5797
5798
5799
5800
5801
5802
5803
5804
5805
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797

class ListCostAllocationTagsRequest < Struct.new(
  :status,
  :tag_keys,
  :type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of CostAllocationTag object that are returned for this request. The AWSGenerated type tags are tags that Amazon Web Services defines and applies to support Amazon Web Services resources for cost allocation purposes. The UserDefined type tags are tags that you define, create, and apply to resources.

Returns:

  • (String)


5797
5798
5799
5800
5801
5802
5803
5804
5805
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797

class ListCostAllocationTagsRequest < Struct.new(
  :status,
  :tag_keys,
  :type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end