Class: Aws::CostExplorer::Types::ListCostCategoryDefinitionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#effective_onString

The date when the cost category was effective.

Returns:



5852
5853
5854
5855
5856
5857
5858
5859
# File 'lib/aws-sdk-costexplorer/types.rb', line 5852

class ListCostCategoryDefinitionsRequest < Struct.new(
  :effective_on,
  :next_token,
  :max_results,
  :supported_resource_types)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The number of entries a paginated response contains.

Returns:



5852
5853
5854
5855
5856
5857
5858
5859
# File 'lib/aws-sdk-costexplorer/types.rb', line 5852

class ListCostCategoryDefinitionsRequest < Struct.new(
  :effective_on,
  :next_token,
  :max_results,
  :supported_resource_types)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.

Returns:



5852
5853
5854
5855
5856
5857
5858
5859
# File 'lib/aws-sdk-costexplorer/types.rb', line 5852

class ListCostCategoryDefinitionsRequest < Struct.new(
  :effective_on,
  :next_token,
  :max_results,
  :supported_resource_types)
  SENSITIVE = []
  include Aws::Structure
end

#supported_resource_typesArray<String>

Filter cost category definitions that are supported by given resource types based on the latest version. If the filter is present, the result only includes Cost Categories that supports input resource type. If the filter isn’t provided, no filtering is applied. The valid values are billing:rispgroupsharing and billing:billingview.

Returns:



5852
5853
5854
5855
5856
5857
5858
5859
# File 'lib/aws-sdk-costexplorer/types.rb', line 5852

class ListCostCategoryDefinitionsRequest < Struct.new(
  :effective_on,
  :next_token,
  :max_results,
  :supported_resource_types)
  SENSITIVE = []
  include Aws::Structure
end