Class: Aws::CostExplorer::Types::MemoryDBInstanceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::MemoryDBInstanceDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Details about the MemoryDB reservations that Amazon Web Services recommends that you purchase.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_generation ⇒ Boolean
Determines whether the recommendation is for a current generation instance.
-
#family ⇒ String
The instance family of the recommended reservation.
-
#node_type ⇒ String
The node type of the recommended reservation.
-
#region ⇒ String
The Amazon Web Services Region of the recommended reservation.
-
#size_flex_eligible ⇒ Boolean
Determines whether the recommended reservation is size flexible.
Instance Attribute Details
#current_generation ⇒ Boolean
Determines whether the recommendation is for a current generation instance.
6025 6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6025 class MemoryDBInstanceDetails < Struct.new( :family, :node_type, :region, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#family ⇒ String
The instance family of the recommended reservation.
6025 6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6025 class MemoryDBInstanceDetails < Struct.new( :family, :node_type, :region, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#node_type ⇒ String
The node type of the recommended reservation.
6025 6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6025 class MemoryDBInstanceDetails < Struct.new( :family, :node_type, :region, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region of the recommended reservation.
6025 6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6025 class MemoryDBInstanceDetails < Struct.new( :family, :node_type, :region, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |
#size_flex_eligible ⇒ Boolean
Determines whether the recommended reservation is size flexible.
6025 6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6025 class MemoryDBInstanceDetails < Struct.new( :family, :node_type, :region, :current_generation, :size_flex_eligible) SENSITIVE = [] include Aws::Structure end |