Class: Aws::CostExplorer::Types::ReservationPurchaseRecommendation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

A specific reservation that Amazon Web Services recommends for purchase.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_scopeString

The account scope that Amazon Web Services recommends that you purchase this instance for. For example, you can purchase this reservation for an entire organization in Amazon Web Services Organizations.

Returns:

  • (String)


6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
# File 'lib/aws-sdk-costexplorer/types.rb', line 6628

class ReservationPurchaseRecommendation < Struct.new(
  :account_scope,
  :lookback_period_in_days,
  :term_in_years,
  :payment_option,
  :service_specification,
  :recommendation_details,
  :recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#lookback_period_in_daysString

How many days of previous usage that Amazon Web Services considers when making this recommendation.

Returns:

  • (String)


6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
# File 'lib/aws-sdk-costexplorer/types.rb', line 6628

class ReservationPurchaseRecommendation < Struct.new(
  :account_scope,
  :lookback_period_in_days,
  :term_in_years,
  :payment_option,
  :service_specification,
  :recommendation_details,
  :recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option for the reservation (for example, AllUpfront or NoUpfront).

Returns:

  • (String)


6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
# File 'lib/aws-sdk-costexplorer/types.rb', line 6628

class ReservationPurchaseRecommendation < Struct.new(
  :account_scope,
  :lookback_period_in_days,
  :term_in_years,
  :payment_option,
  :service_specification,
  :recommendation_details,
  :recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_detailsArray<Types::ReservationPurchaseRecommendationDetail>

Details about the recommended purchases.



6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
# File 'lib/aws-sdk-costexplorer/types.rb', line 6628

class ReservationPurchaseRecommendation < Struct.new(
  :account_scope,
  :lookback_period_in_days,
  :term_in_years,
  :payment_option,
  :service_specification,
  :recommendation_details,
  :recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_summaryTypes::ReservationPurchaseRecommendationSummary

A summary about the recommended purchase.



6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
# File 'lib/aws-sdk-costexplorer/types.rb', line 6628

class ReservationPurchaseRecommendation < Struct.new(
  :account_scope,
  :lookback_period_in_days,
  :term_in_years,
  :payment_option,
  :service_specification,
  :recommendation_details,
  :recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#service_specificationTypes::ServiceSpecification

Hardware specifications for the service that you want recommendations for.



6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
# File 'lib/aws-sdk-costexplorer/types.rb', line 6628

class ReservationPurchaseRecommendation < Struct.new(
  :account_scope,
  :lookback_period_in_days,
  :term_in_years,
  :payment_option,
  :service_specification,
  :recommendation_details,
  :recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#term_in_yearsString

The term of the reservation that you want recommendations for, in years.

Returns:

  • (String)


6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
# File 'lib/aws-sdk-costexplorer/types.rb', line 6628

class ReservationPurchaseRecommendation < Struct.new(
  :account_scope,
  :lookback_period_in_days,
  :term_in_years,
  :payment_option,
  :service_specification,
  :recommendation_details,
  :recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end