Class: Aws::CostExplorer::Types::ReservationPurchaseRecommendationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::ReservationPurchaseRecommendationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
A summary about this recommendation, such as the currency code, the amount that Amazon Web Services estimates that you could save, and the total amount of reservation to purchase.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code used for this recommendation.
-
#total_estimated_monthly_savings_amount ⇒ String
The total amount that Amazon Web Services estimates that this recommendation could save you in a month.
-
#total_estimated_monthly_savings_percentage ⇒ String
The total amount that Amazon Web Services estimates that this recommendation could save you in a month, as a percentage of your costs.
Instance Attribute Details
#currency_code ⇒ String
The currency code used for this recommendation.
6847 6848 6849 6850 6851 6852 6853 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6847 class ReservationPurchaseRecommendationSummary < Struct.new( :total_estimated_monthly_savings_amount, :total_estimated_monthly_savings_percentage, :currency_code) SENSITIVE = [] include Aws::Structure end |
#total_estimated_monthly_savings_amount ⇒ String
The total amount that Amazon Web Services estimates that this recommendation could save you in a month.
6847 6848 6849 6850 6851 6852 6853 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6847 class ReservationPurchaseRecommendationSummary < Struct.new( :total_estimated_monthly_savings_amount, :total_estimated_monthly_savings_percentage, :currency_code) SENSITIVE = [] include Aws::Structure end |
#total_estimated_monthly_savings_percentage ⇒ String
The total amount that Amazon Web Services estimates that this recommendation could save you in a month, as a percentage of your costs.
6847 6848 6849 6850 6851 6852 6853 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 6847 class ReservationPurchaseRecommendationSummary < Struct.new( :total_estimated_monthly_savings_amount, :total_estimated_monthly_savings_percentage, :currency_code) SENSITIVE = [] include Aws::Structure end |