Class: Aws::CostExplorer::Types::SavingsPlans

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

The Savings Plans commitment details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_familyString

The instance family of the Savings Plans commitment.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
# File 'lib/aws-sdk-costexplorer/types.rb', line 7231

class SavingsPlans < Struct.new(
  :payment_option,
  :savings_plans_type,
  :region,
  :instance_family,
  :term_in_years,
  :savings_plans_commitment,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#offering_idString

The unique ID that’s used to distinguish Savings Plans commitments from one another.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
# File 'lib/aws-sdk-costexplorer/types.rb', line 7231

class SavingsPlans < Struct.new(
  :payment_option,
  :savings_plans_type,
  :region,
  :instance_family,
  :term_in_years,
  :savings_plans_commitment,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option for the Savings Plans commitment.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
# File 'lib/aws-sdk-costexplorer/types.rb', line 7231

class SavingsPlans < Struct.new(
  :payment_option,
  :savings_plans_type,
  :region,
  :instance_family,
  :term_in_years,
  :savings_plans_commitment,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Region associated with the Savings Plans commitment.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
# File 'lib/aws-sdk-costexplorer/types.rb', line 7231

class SavingsPlans < Struct.new(
  :payment_option,
  :savings_plans_type,
  :region,
  :instance_family,
  :term_in_years,
  :savings_plans_commitment,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#savings_plans_commitmentFloat

The Savings Plans commitment.

Returns:

  • (Float)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
# File 'lib/aws-sdk-costexplorer/types.rb', line 7231

class SavingsPlans < Struct.new(
  :payment_option,
  :savings_plans_type,
  :region,
  :instance_family,
  :term_in_years,
  :savings_plans_commitment,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#savings_plans_typeString

The Savings Plans type.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
# File 'lib/aws-sdk-costexplorer/types.rb', line 7231

class SavingsPlans < Struct.new(
  :payment_option,
  :savings_plans_type,
  :region,
  :instance_family,
  :term_in_years,
  :savings_plans_commitment,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#term_in_yearsString

The term that you want the Savings Plans commitment for.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
# File 'lib/aws-sdk-costexplorer/types.rb', line 7231

class SavingsPlans < Struct.new(
  :payment_option,
  :savings_plans_type,
  :region,
  :instance_family,
  :term_in_years,
  :savings_plans_commitment,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end