Class: Aws::CostExplorer::Types::SavingsPlansCoverage
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::SavingsPlansCoverage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
The amount of Savings Plans eligible usage that’s covered by Savings Plans. All calculations consider the On-Demand equivalent of your Savings Plans usage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
The attribute that applies to a specific
Dimension. -
#coverage ⇒ Types::SavingsPlansCoverageData
The amount of Savings Plans eligible usage that the Savings Plans covered.
-
#time_period ⇒ Types::DateInterval
The time period of the request.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
The attribute that applies to a specific Dimension.
7290 7291 7292 7293 7294 7295 7296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7290 class SavingsPlansCoverage < Struct.new( :attributes, :coverage, :time_period) SENSITIVE = [] include Aws::Structure end |
#coverage ⇒ Types::SavingsPlansCoverageData
The amount of Savings Plans eligible usage that the Savings Plans covered.
7290 7291 7292 7293 7294 7295 7296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7290 class SavingsPlansCoverage < Struct.new( :attributes, :coverage, :time_period) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::DateInterval
The time period of the request.
7290 7291 7292 7293 7294 7295 7296 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7290 class SavingsPlansCoverage < Struct.new( :attributes, :coverage, :time_period) SENSITIVE = [] include Aws::Structure end |