Class: Aws::CostExplorer::Types::SavingsPlansDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

The attribute details on a specific Savings Plan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_familyString

A group of instance types that Savings Plans applies to.



7352
7353
7354
7355
7356
7357
7358
# File 'lib/aws-sdk-costexplorer/types.rb', line 7352

class SavingsPlansDetails < Struct.new(
  :region,
  :instance_family,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#offering_idString

The unique ID that's used to distinguish Savings Plans from one another.



7352
7353
7354
7355
7356
7357
7358
# File 'lib/aws-sdk-costexplorer/types.rb', line 7352

class SavingsPlansDetails < Struct.new(
  :region,
  :instance_family,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

A collection of Amazon Web Services resources in a geographic area. Each Amazon Web Services Region is isolated and independent of the other Regions.



7352
7353
7354
7355
7356
7357
7358
# File 'lib/aws-sdk-costexplorer/types.rb', line 7352

class SavingsPlansDetails < Struct.new(
  :region,
  :instance_family,
  :offering_id)
  SENSITIVE = []
  include Aws::Structure
end