Class: Aws::CostExplorer::Types::SavingsPlansPurchaseAnalysisDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Details about the Savings Plans purchase analysis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_metadataString

Additional metadata that might be applicable to the commitment.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#currency_codeString

The currency code used for the analysis.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#current_average_coverageString

The average value of hourly coverage over the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#current_average_hourly_on_demand_spendString

The average value of hourly On-Demand spend over the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#current_maximum_hourly_on_demand_spendString

The highest value of hourly On-Demand spend over the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#current_minimum_hourly_on_demand_spendString

The lowest value of hourly On-Demand spend over the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#current_on_demand_spendString

The current total On-Demand spend over the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_average_coverageString

The estimated coverage of the Savings Plan.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_average_utilizationString

The estimated utilization of the Savings Plan.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_commitment_costString

The estimated cost of the Savings Plan over the length of the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_monthly_savings_amountString

The estimated monthly savings amount based on the Savings Plan.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_on_demand_costString

The remaining On-Demand cost estimated to not be covered by the Savings Plan over the length of the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_on_demand_cost_with_current_commitmentString

The estimated On-Demand cost you expect with no additional commitment based on your usage of the selected time period and the Savings Plan you own.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_roiString

The estimated return on investment that's based on the Savings Plan and estimated savings. This is calculated as estimatedSavingsAmount/estimatedSPCost*100.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_savings_amountString

The estimated savings amount that's based on the Savings Plan over the length of the lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_savings_percentageString

The estimated savings percentage relative to the total cost over the cost calculation lookback period.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#existing_hourly_commitmentString

The existing hourly commitment for the Savings Plan type.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#hourly_commitment_to_purchaseString

The recommended or custom hourly commitment.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#latest_usage_timestampString

The date and time of the last hour that went into the analysis.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#lookback_period_in_hoursString

The lookback period in hours that's used to generate the analysis.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#metrics_over_lookback_periodArray<Types::RecommendationDetailHourlyMetrics>

The related hourly cost, coverage, and utilization metrics over the lookback period.



7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_costString

The upfront cost of the Savings Plan based on the selected payment option.

Returns:

  • (String)


7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-costexplorer/types.rb', line 7512

class SavingsPlansPurchaseAnalysisDetails < Struct.new(
  :currency_code,
  :lookback_period_in_hours,
  :current_average_coverage,
  :current_average_hourly_on_demand_spend,
  :current_maximum_hourly_on_demand_spend,
  :current_minimum_hourly_on_demand_spend,
  :current_on_demand_spend,
  :existing_hourly_commitment,
  :hourly_commitment_to_purchase,
  :estimated_average_coverage,
  :estimated_average_utilization,
  :estimated_monthly_savings_amount,
  :estimated_on_demand_cost,
  :estimated_on_demand_cost_with_current_commitment,
  :estimated_roi,
  :estimated_savings_amount,
  :estimated_savings_percentage,
  :estimated_commitment_cost,
  :latest_usage_timestamp,
  :upfront_cost,
  :additional_metadata,
  :metrics_over_lookback_period)
  SENSITIVE = []
  include Aws::Structure
end