Class: Aws::CostExplorer::Types::SavingsPlansPurchaseRecommendation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Contains your request parameters, Savings Plan Recommendations Summary, and Details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_scopeString

The account scope that you want your recommendations for. Amazon Web Services calculates recommendations that include the management account and member accounts if the value is set to PAYER. If the value is LINKED, recommendations are calculated for individual member accounts only.

Returns:



7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579

class SavingsPlansPurchaseRecommendation < Struct.new(
  :account_scope,
  :savings_plans_type,
  :term_in_years,
  :payment_option,
  :lookback_period_in_days,
  :savings_plans_purchase_recommendation_details,
  :savings_plans_purchase_recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#lookback_period_in_daysString

The lookback period in days that's used to generate the recommendation.

Returns:



7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579

class SavingsPlansPurchaseRecommendation < Struct.new(
  :account_scope,
  :savings_plans_type,
  :term_in_years,
  :payment_option,
  :lookback_period_in_days,
  :savings_plans_purchase_recommendation_details,
  :savings_plans_purchase_recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option that's used to generate the recommendation.

Returns:



7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579

class SavingsPlansPurchaseRecommendation < Struct.new(
  :account_scope,
  :savings_plans_type,
  :term_in_years,
  :payment_option,
  :lookback_period_in_days,
  :savings_plans_purchase_recommendation_details,
  :savings_plans_purchase_recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#savings_plans_purchase_recommendation_detailsArray<Types::SavingsPlansPurchaseRecommendationDetail>

Details for the Savings Plans that we recommend that you purchase to cover existing Savings Plans eligible workloads.

Returns:



7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579

class SavingsPlansPurchaseRecommendation < Struct.new(
  :account_scope,
  :savings_plans_type,
  :term_in_years,
  :payment_option,
  :lookback_period_in_days,
  :savings_plans_purchase_recommendation_details,
  :savings_plans_purchase_recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#savings_plans_purchase_recommendation_summaryTypes::SavingsPlansPurchaseRecommendationSummary

Summary metrics for your Savings Plans Recommendations.

Returns:



7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579

class SavingsPlansPurchaseRecommendation < Struct.new(
  :account_scope,
  :savings_plans_type,
  :term_in_years,
  :payment_option,
  :lookback_period_in_days,
  :savings_plans_purchase_recommendation_details,
  :savings_plans_purchase_recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#savings_plans_typeString

The requested Savings Plans recommendation type.

Returns:



7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579

class SavingsPlansPurchaseRecommendation < Struct.new(
  :account_scope,
  :savings_plans_type,
  :term_in_years,
  :payment_option,
  :lookback_period_in_days,
  :savings_plans_purchase_recommendation_details,
  :savings_plans_purchase_recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end

#term_in_yearsString

The Savings Plans recommendation term in years. It's used to generate the recommendation.

Returns:



7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579

class SavingsPlansPurchaseRecommendation < Struct.new(
  :account_scope,
  :savings_plans_type,
  :term_in_years,
  :payment_option,
  :lookback_period_in_days,
  :savings_plans_purchase_recommendation_details,
  :savings_plans_purchase_recommendation_summary)
  SENSITIVE = []
  include Aws::Structure
end