Class: Aws::CostExplorer::Types::SavingsPlansPurchaseRecommendationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::SavingsPlansPurchaseRecommendationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Summary metrics for your Savings Plans Purchase Recommendations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code that Amazon Web Services used to generate the recommendations and present potential savings.
-
#current_on_demand_spend ⇒ String
The current total on demand spend of the applicable usage types over the lookback period.
-
#daily_commitment_to_purchase ⇒ String
The recommended Savings Plans cost on a daily (24 hourly) basis.
-
#estimated_monthly_savings_amount ⇒ String
The estimated monthly savings amount that’s based on the recommended Savings Plans purchase.
-
#estimated_on_demand_cost_with_current_commitment ⇒ String
The estimated On-Demand costs you expect with no additional commitment.
-
#estimated_roi ⇒ String
The estimated return on investment that’s based on the recommended Savings Plans and estimated savings.
-
#estimated_savings_amount ⇒ String
The estimated total savings over the lookback period, based on the purchase of the recommended Savings Plans.
-
#estimated_savings_percentage ⇒ String
The estimated savings relative to the total cost of On-Demand usage, over the lookback period.
-
#estimated_total_cost ⇒ String
The estimated total cost of the usage after purchasing the recommended Savings Plans.
-
#hourly_commitment_to_purchase ⇒ String
The recommended hourly commitment that’s based on the recommendation parameters.
-
#total_recommendation_count ⇒ String
The aggregate number of Savings Plans recommendations that exist for your account.
Instance Attribute Details
#currency_code ⇒ String
The currency code that Amazon Web Services used to generate the recommendations and present potential savings.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#current_on_demand_spend ⇒ String
The current total on demand spend of the applicable usage types over the lookback period.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#daily_commitment_to_purchase ⇒ String
The recommended Savings Plans cost on a daily (24 hourly) basis.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#estimated_monthly_savings_amount ⇒ String
The estimated monthly savings amount that’s based on the recommended Savings Plans purchase.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#estimated_on_demand_cost_with_current_commitment ⇒ String
The estimated On-Demand costs you expect with no additional commitment. It’s based on your usage of the selected time period and the Savings Plans you own.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#estimated_roi ⇒ String
The estimated return on investment that’s based on the recommended Savings Plans and estimated savings.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#estimated_savings_amount ⇒ String
The estimated total savings over the lookback period, based on the purchase of the recommended Savings Plans.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#estimated_savings_percentage ⇒ String
The estimated savings relative to the total cost of On-Demand usage, over the lookback period. This is calculated as estimatedSavingsAmount/ CurrentOnDemandSpend*100.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#estimated_total_cost ⇒ String
The estimated total cost of the usage after purchasing the recommended Savings Plans. This is a sum of the cost of Savings Plans during this term, and the remaining On-Demand usage.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#hourly_commitment_to_purchase ⇒ String
The recommended hourly commitment that’s based on the recommendation parameters.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |
#total_recommendation_count ⇒ String
The aggregate number of Savings Plans recommendations that exist for your account.
7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7778 class SavingsPlansPurchaseRecommendationSummary < Struct.new( :estimated_roi, :currency_code, :estimated_total_cost, :current_on_demand_spend, :estimated_savings_amount, :total_recommendation_count, :daily_commitment_to_purchase, :hourly_commitment_to_purchase, :estimated_savings_percentage, :estimated_monthly_savings_amount, :estimated_on_demand_cost_with_current_commitment) SENSITIVE = [] include Aws::Structure end |