Class: Aws::CostExplorer::Types::SavingsPlansUtilizationAggregates

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

The aggregated utilization metrics for your Savings Plans usage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amortized_commitmentTypes::SavingsPlansAmortizedCommitment

The total amortized commitment for a Savings Plans. This includes the sum of the upfront and recurring Savings Plans fees.

Returns:



7880
7881
7882
7883
7884
7885
7886
# File 'lib/aws-sdk-costexplorer/types.rb', line 7880

class SavingsPlansUtilizationAggregates < Struct.new(
  :utilization,
  :savings,
  :amortized_commitment)
  SENSITIVE = []
  include Aws::Structure
end

#savingsTypes::SavingsPlansSavings

The amount that's saved by using existing Savings Plans. Savings returns both net savings from Savings Plans and also the onDemandCostEquivalent of the Savings Plans when considering the utilization rate.

Returns:



7880
7881
7882
7883
7884
7885
7886
# File 'lib/aws-sdk-costexplorer/types.rb', line 7880

class SavingsPlansUtilizationAggregates < Struct.new(
  :utilization,
  :savings,
  :amortized_commitment)
  SENSITIVE = []
  include Aws::Structure
end

#utilizationTypes::SavingsPlansUtilization

A ratio of your effectiveness of using existing Savings Plans to apply to workloads that are Savings Plans eligible.

Returns:



7880
7881
7882
7883
7884
7885
7886
# File 'lib/aws-sdk-costexplorer/types.rb', line 7880

class SavingsPlansUtilizationAggregates < Struct.new(
  :utilization,
  :savings,
  :amortized_commitment)
  SENSITIVE = []
  include Aws::Structure
end