Class: Aws::CostExplorer::Types::SavingsPlansUtilizationDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::SavingsPlansUtilizationDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
A single daily or monthly Savings Plans utilization rate and details
for your account. A management account in an organization have access
to member accounts. You can use GetDimensionValues to determine the
possible dimension values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amortized_commitment ⇒ Types::SavingsPlansAmortizedCommitment
The total amortized commitment for a Savings Plans.
-
#attributes ⇒ Hash<String,String>
The attribute that applies to a specific
Dimension. -
#savings ⇒ Types::SavingsPlansSavings
The amount saved by using existing Savings Plans.
-
#savings_plan_arn ⇒ String
The unique Amazon Resource Name (ARN) for a particular Savings Plan.
-
#utilization ⇒ Types::SavingsPlansUtilization
A ratio of your effectiveness of using existing Savings Plans to apply to workloads that are Savings Plans eligible.
Instance Attribute Details
#amortized_commitment ⇒ Types::SavingsPlansAmortizedCommitment
The total amortized commitment for a Savings Plans. Includes the sum of the upfront and recurring Savings Plans fees.
7954 7955 7956 7957 7958 7959 7960 7961 7962 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7954 class SavingsPlansUtilizationDetail < Struct.new( :savings_plan_arn, :attributes, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#attributes ⇒ Hash<String,String>
The attribute that applies to a specific Dimension.
7954 7955 7956 7957 7958 7959 7960 7961 7962 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7954 class SavingsPlansUtilizationDetail < Struct.new( :savings_plan_arn, :attributes, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#savings ⇒ Types::SavingsPlansSavings
The amount saved by using existing Savings Plans. Savings returns
both net savings from savings plans and also the
onDemandCostEquivalent of the Savings Plans when considering the
utilization rate.
7954 7955 7956 7957 7958 7959 7960 7961 7962 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7954 class SavingsPlansUtilizationDetail < Struct.new( :savings_plan_arn, :attributes, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#savings_plan_arn ⇒ String
The unique Amazon Resource Name (ARN) for a particular Savings Plan.
7954 7955 7956 7957 7958 7959 7960 7961 7962 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7954 class SavingsPlansUtilizationDetail < Struct.new( :savings_plan_arn, :attributes, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#utilization ⇒ Types::SavingsPlansUtilization
A ratio of your effectiveness of using existing Savings Plans to apply to workloads that are Savings Plans eligible.
7954 7955 7956 7957 7958 7959 7960 7961 7962 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7954 class SavingsPlansUtilizationDetail < Struct.new( :savings_plan_arn, :attributes, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |