Class: Aws::CostExplorer::Types::TooManyTagsException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::TooManyTagsException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Can occur if you specify a number of tags for a resource greater than the maximum 50 user tags per resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
8283 8284 8285 8286 8287 8288 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8283 class TooManyTagsException < Struct.new( :message, :resource_name) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
8283 8284 8285 8286 8287 8288 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8283 class TooManyTagsException < Struct.new( :message, :resource_name) SENSITIVE = [] include Aws::Structure end |