Class: Aws::CostExplorer::Types::UpdateAnomalySubscriptionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::UpdateAnomalySubscriptionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#frequency ⇒ String
The update to the frequency value that subscribers receive notifications.
-
#monitor_arn_list ⇒ Array<String>
A list of cost anomaly monitor ARNs.
-
#subscribers ⇒ Array<Types::Subscriber>
The update to the subscriber list.
-
#subscription_arn ⇒ String
A cost anomaly subscription Amazon Resource Name (ARN).
-
#subscription_name ⇒ String
The new name of the subscription.
-
#threshold ⇒ Float
(deprecated).
-
#threshold_expression ⇒ Types::Expression
The update to the [Expression][1] object used to specify the anomalies that you want to generate alerts for.
Instance Attribute Details
#frequency ⇒ String
The update to the frequency value that subscribers receive notifications.
8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8504 class UpdateAnomalySubscriptionRequest < Struct.new( :subscription_arn, :threshold, :frequency, :monitor_arn_list, :subscribers, :subscription_name, :threshold_expression) SENSITIVE = [] include Aws::Structure end |
#monitor_arn_list ⇒ Array<String>
A list of cost anomaly monitor ARNs.
8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8504 class UpdateAnomalySubscriptionRequest < Struct.new( :subscription_arn, :threshold, :frequency, :monitor_arn_list, :subscribers, :subscription_name, :threshold_expression) SENSITIVE = [] include Aws::Structure end |
#subscribers ⇒ Array<Types::Subscriber>
The update to the subscriber list.
8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8504 class UpdateAnomalySubscriptionRequest < Struct.new( :subscription_arn, :threshold, :frequency, :monitor_arn_list, :subscribers, :subscription_name, :threshold_expression) SENSITIVE = [] include Aws::Structure end |
#subscription_arn ⇒ String
A cost anomaly subscription Amazon Resource Name (ARN).
8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8504 class UpdateAnomalySubscriptionRequest < Struct.new( :subscription_arn, :threshold, :frequency, :monitor_arn_list, :subscribers, :subscription_name, :threshold_expression) SENSITIVE = [] include Aws::Structure end |
#subscription_name ⇒ String
The new name of the subscription.
8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8504 class UpdateAnomalySubscriptionRequest < Struct.new( :subscription_arn, :threshold, :frequency, :monitor_arn_list, :subscribers, :subscription_name, :threshold_expression) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
(deprecated)
The update to the threshold value for receiving notifications.
This field has been deprecated. To update a threshold, use ThresholdExpression. Continued use of Threshold will be treated as shorthand syntax for a ThresholdExpression.
You can specify either Threshold or ThresholdExpression, but not both.
8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8504 class UpdateAnomalySubscriptionRequest < Struct.new( :subscription_arn, :threshold, :frequency, :monitor_arn_list, :subscribers, :subscription_name, :threshold_expression) SENSITIVE = [] include Aws::Structure end |
#threshold_expression ⇒ Types::Expression
The update to the Expression object used to specify the
anomalies that you want to generate alerts for. This supports
dimensions and nested expressions. The supported dimensions are
ANOMALY_TOTAL_IMPACT_ABSOLUTE and
ANOMALY_TOTAL_IMPACT_PERCENTAGE, corresponding to an anomaly’s
TotalImpact and TotalImpactPercentage, respectively (see Impact
for more details). The supported nested expression types are AND
and OR. The match option GREATER_THAN_OR_EQUAL is required.
Values must be numbers between 0 and 10,000,000,000 in string
format.
You can specify either Threshold or ThresholdExpression, but not both.
The following are examples of valid ThresholdExpressions:
-
Absolute threshold:
{ "Dimensions": { "Key": "ANOMALY_TOTAL_IMPACT_ABSOLUTE", "MatchOptions": [ "GREATER_THAN_OR_EQUAL" ], "Values": [ "100" ] } } -
Percentage threshold:
{ "Dimensions": { "Key": "ANOMALY_TOTAL_IMPACT_PERCENTAGE", "MatchOptions": [ "GREATER_THAN_OR_EQUAL" ], "Values": [ "100" ] } } -
ANDtwo thresholds together:{ "And": [ { "Dimensions": { "Key": "ANOMALY_TOTAL_IMPACT_ABSOLUTE", "MatchOptions": [ "GREATER_THAN_OR_EQUAL" ], "Values": [ "100" ] } }, { "Dimensions": { "Key": "ANOMALY_TOTAL_IMPACT_PERCENTAGE", "MatchOptions": [ "GREATER_THAN_OR_EQUAL" ], "Values": [ "100" ] } } ] } -
ORtwo thresholds together:{ "Or": [ { "Dimensions": { "Key": "ANOMALY_TOTAL_IMPACT_ABSOLUTE", "MatchOptions": [ "GREATER_THAN_OR_EQUAL" ], "Values": [ "100" ] } }, { "Dimensions": { "Key": "ANOMALY_TOTAL_IMPACT_PERCENTAGE", "MatchOptions": [ "GREATER_THAN_OR_EQUAL" ], "Values": [ "100" ] } } ] }
8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8504 class UpdateAnomalySubscriptionRequest < Struct.new( :subscription_arn, :threshold, :frequency, :monitor_arn_list, :subscribers, :subscription_name, :threshold_expression) SENSITIVE = [] include Aws::Structure end |