Class: Aws::CostExplorer::Types::UpdateCostCategoryDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cost_category_arnString

The unique identifier for your cost category.

Returns:

  • (String)


8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
# File 'lib/aws-sdk-costexplorer/types.rb', line 8606

class UpdateCostCategoryDefinitionRequest < Struct.new(
  :cost_category_arn,
  :effective_start,
  :rule_version,
  :rules,
  :default_value,
  :split_charge_rules)
  SENSITIVE = []
  include Aws::Structure
end

#default_valueString

The default value for the cost category.

Returns:

  • (String)


8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
# File 'lib/aws-sdk-costexplorer/types.rb', line 8606

class UpdateCostCategoryDefinitionRequest < Struct.new(
  :cost_category_arn,
  :effective_start,
  :rule_version,
  :rules,
  :default_value,
  :split_charge_rules)
  SENSITIVE = []
  include Aws::Structure
end

#effective_startString

The cost category’s effective start date. It can only be a billing start date (first day of the month). If the date isn’t provided, it’s the first day of the current month. Dates can’t be before the previous twelve months, or in the future.

Returns:

  • (String)


8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
# File 'lib/aws-sdk-costexplorer/types.rb', line 8606

class UpdateCostCategoryDefinitionRequest < Struct.new(
  :cost_category_arn,
  :effective_start,
  :rule_version,
  :rules,
  :default_value,
  :split_charge_rules)
  SENSITIVE = []
  include Aws::Structure
end

#rule_versionString

The rule schema version in this particular cost category.

Returns:

  • (String)


8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
# File 'lib/aws-sdk-costexplorer/types.rb', line 8606

class UpdateCostCategoryDefinitionRequest < Struct.new(
  :cost_category_arn,
  :effective_start,
  :rule_version,
  :rules,
  :default_value,
  :split_charge_rules)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::CostCategoryRule>

The Expression object used to categorize costs. For more information, see [CostCategoryRule ][1].

[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html

Returns:



8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
# File 'lib/aws-sdk-costexplorer/types.rb', line 8606

class UpdateCostCategoryDefinitionRequest < Struct.new(
  :cost_category_arn,
  :effective_start,
  :rule_version,
  :rules,
  :default_value,
  :split_charge_rules)
  SENSITIVE = []
  include Aws::Structure
end

#split_charge_rulesArray<Types::CostCategorySplitChargeRule>

The split charge rules used to allocate your charges between your cost category values.



8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
# File 'lib/aws-sdk-costexplorer/types.rb', line 8606

class UpdateCostCategoryDefinitionRequest < Struct.new(
  :cost_category_arn,
  :effective_start,
  :rule_version,
  :rules,
  :default_value,
  :split_charge_rules)
  SENSITIVE = []
  include Aws::Structure
end