Class: Aws::CostExplorer::Types::GetSavingsPlansCoverageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::Expression

Filters Savings Plans coverage data by dimensions. You can filter data for Savings Plans usage with the following dimensions:

  • LINKED_ACCOUNT

  • REGION

  • SERVICE

  • INSTANCE_FAMILY

GetSavingsPlansCoverage uses the same [Expression] object as the other operations, but only AND is supported among each dimension. If there are multiple values for a dimension, they are OR’d together.

Cost category is also supported.

[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_Expression.html



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#granularityString

The granularity of the Amazon Web Services cost data for your Savings Plans. Granularity can’t be set if GroupBy is set.

The GetSavingsPlansCoverage operation supports only DAILY and MONTHLY granularities.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#group_byArray<Types::GroupDefinition>

You can group the data using the attributes INSTANCE_FAMILY, REGION, or SERVICE.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The number of items to be returned in a response. The default is 20, with a minimum value of 1.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<String>

The measurement that you want your Savings Plans coverage reported in. The only valid value is SpendCoveredBySavingsPlans.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byTypes::SortDefinition

The value that you want to sort the data by.

The following values are supported for Key:

  • SpendCoveredBySavingsPlan

  • OnDemandCost

  • CoveragePercentage

  • TotalCost

  • InstanceFamily

  • Region

  • Service

The supported values for SortOrder are ASCENDING and DESCENDING.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#time_periodTypes::DateInterval

The time period that you want the usage and costs for. The Start date must be within 13 months. The End date must be after the Start date, and before the current date. Future dates can’t be used as an End date.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871

class GetSavingsPlansCoverageRequest < Struct.new(
  :time_period,
  :group_by,
  :granularity,
  :filter,
  :metrics,
  :next_token,
  :max_results,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end