Class: Aws::CostExplorer::Types::GetSavingsPlansCoverageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetSavingsPlansCoverageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::Expression
Filters Savings Plans coverage data by dimensions.
-
#granularity ⇒ String
The granularity of the Amazon Web Services cost data for your Savings Plans.
-
#group_by ⇒ Array<Types::GroupDefinition>
You can group the data using the attributes
INSTANCE_FAMILY,REGION, orSERVICE. -
#max_results ⇒ Integer
The number of items to be returned in a response.
-
#metrics ⇒ Array<String>
The measurement that you want your Savings Plans coverage reported in.
-
#next_token ⇒ String
The token to retrieve the next set of results.
-
#sort_by ⇒ Types::SortDefinition
The value that you want to sort the data by.
-
#time_period ⇒ Types::DateInterval
The time period that you want the usage and costs for.
Instance Attribute Details
#filter ⇒ Types::Expression
Filters Savings Plans coverage data by dimensions. You can filter data for Savings Plans usage with the following dimensions:
-
LINKED_ACCOUNT -
REGION -
SERVICE -
INSTANCE_FAMILY
GetSavingsPlansCoverage uses the same [Expression] object as the other operations, but only AND is supported among each dimension. If there are multiple values for a dimension, they are OR’d together.
Cost category is also supported.
[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_Expression.html
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#granularity ⇒ String
The granularity of the Amazon Web Services cost data for your Savings Plans. Granularity can’t be set if GroupBy is set.
The GetSavingsPlansCoverage operation supports only DAILY and MONTHLY granularities.
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<Types::GroupDefinition>
You can group the data using the attributes INSTANCE_FAMILY, REGION, or SERVICE.
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The number of items to be returned in a response. The default is 20, with a minimum value of 1.
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<String>
The measurement that you want your Savings Plans coverage reported in. The only valid value is SpendCoveredBySavingsPlans.
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ Types::SortDefinition
The value that you want to sort the data by.
The following values are supported for Key:
-
SpendCoveredBySavingsPlan -
OnDemandCost -
CoveragePercentage -
TotalCost -
InstanceFamily -
Region -
Service
The supported values for SortOrder are ASCENDING and DESCENDING.
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::DateInterval
The time period that you want the usage and costs for. The Start date must be within 13 months. The End date must be after the Start date, and before the current date. Future dates can’t be used as an End date.
4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4871 class GetSavingsPlansCoverageRequest < Struct.new( :time_period, :group_by, :granularity, :filter, :metrics, :next_token, :max_results, :sort_by) SENSITIVE = [] include Aws::Structure end |