Class: Aws::CostExplorer::Types::GetSavingsPlansPurchaseRecommendationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetSavingsPlansPurchaseRecommendationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_scope ⇒ String
The account scope that you want your recommendations for.
-
#filter ⇒ Types::Expression
You can filter your recommendations by Account ID with the
LINKED_ACCOUNTdimension. -
#lookback_period_in_days ⇒ String
The lookback period that’s used to generate the recommendation.
-
#next_page_token ⇒ String
The token to retrieve the next set of results.
-
#page_size ⇒ Integer
The number of recommendations that you want returned in a single response object.
-
#payment_option ⇒ String
The payment option that’s used to generate these recommendations.
-
#savings_plans_type ⇒ String
The Savings Plans recommendation type that’s requested.
-
#term_in_years ⇒ String
The savings plan recommendation term that’s used to generate these recommendations.
Instance Attribute Details
#account_scope ⇒ String
The account scope that you want your recommendations for. Amazon Web Services calculates recommendations including the management account and member accounts if the value is set to PAYER. If the value is LINKED, recommendations are calculated for individual member accounts only.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::Expression
You can filter your recommendations by Account ID with the LINKED_ACCOUNT dimension. To filter your recommendations by Account ID, specify Key as LINKED_ACCOUNT and Value as the comma-separated Acount ID(s) that you want to see Savings Plans purchase recommendations for.
For GetSavingsPlansPurchaseRecommendation, the Filter doesn’t include CostCategories or Tags. It only includes Dimensions. With Dimensions, Key must be LINKED_ACCOUNT and Value can be a single Account ID or multiple comma-separated Account IDs that you want to see Savings Plans Purchase Recommendations for. AND and OR operators are not supported.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |
#lookback_period_in_days ⇒ String
The lookback period that’s used to generate the recommendation.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of recommendations that you want returned in a single response object.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option that’s used to generate these recommendations.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |
#savings_plans_type ⇒ String
The Savings Plans recommendation type that’s requested.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |
#term_in_years ⇒ String
The savings plan recommendation term that’s used to generate these recommendations.
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 4956 class GetSavingsPlansPurchaseRecommendationRequest < Struct.new( :savings_plans_type, :term_in_years, :payment_option, :account_scope, :next_page_token, :page_size, :lookback_period_in_days, :filter) SENSITIVE = [] include Aws::Structure end |