Class: Aws::CostExplorer::Types::GetUsageForecastRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::GetUsageForecastRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_view_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies a specific billing view.
-
#filter ⇒ Types::Expression
The filters that you want to use to filter your forecast.
-
#granularity ⇒ String
How granular you want the forecast to be.
-
#metric ⇒ String
Which metric Cost Explorer uses to create your forecast.
-
#prediction_interval_level ⇒ Integer
Amazon Web Services Cost Explorer always returns the mean forecast as a single point.
-
#time_period ⇒ Types::DateInterval
The start and end dates of the period that you want to retrieve usage forecast for.
Instance Attribute Details
#billing_view_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies a specific billing view. The ARN is used to specify which particular billing view you want to interact with or retrieve information from when making API calls related to Amazon Web Services Billing and Cost Management features. The BillingViewArn can be retrieved by calling the ListBillingViews API.
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5498 class GetUsageForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::Expression
The filters that you want to use to filter your forecast. The GetUsageForecast API supports filtering by the following dimensions:
-
AZ -
INSTANCE_TYPE -
LINKED_ACCOUNT -
LINKED_ACCOUNT_NAME -
OPERATION -
PURCHASE_TYPE -
REGION -
SERVICE -
USAGE_TYPE -
USAGE_TYPE_GROUP -
RECORD_TYPE -
OPERATING_SYSTEM -
TENANCY -
SCOPE -
PLATFORM -
SUBSCRIPTION_ID -
LEGAL_ENTITY_NAME -
DEPLOYMENT_OPTION -
DATABASE_ENGINE -
INSTANCE_TYPE_FAMILY -
BILLING_ENTITY -
RESERVATION_ID -
SAVINGS_PLAN_ARN
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5498 class GetUsageForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#granularity ⇒ String
How granular you want the forecast to be. You can get 3 months of DAILY forecasts or 18 months of MONTHLY forecasts.
The GetUsageForecast operation supports only DAILY and MONTHLY granularities.
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5498 class GetUsageForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ String
Which metric Cost Explorer uses to create your forecast.
Valid values for a GetUsageForecast call are the following:
-
USAGE_QUANTITY
-
NORMALIZED_USAGE_AMOUNT
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5498 class GetUsageForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#prediction_interval_level ⇒ Integer
Amazon Web Services Cost Explorer always returns the mean forecast as a single point. You can request a prediction interval around the mean by specifying a confidence level. The higher the confidence level, the more confident Cost Explorer is about the actual value falling in the prediction interval. Higher confidence levels result in wider prediction intervals.
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5498 class GetUsageForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::DateInterval
The start and end dates of the period that you want to retrieve usage forecast for. The start date is included in the period, but the end date isn’t included in the period. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01. The start date must be equal to or later than the current date to avoid a validation error.
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5498 class GetUsageForecastRequest < Struct.new( :time_period, :metric, :granularity, :filter, :billing_view_arn, :prediction_interval_level) SENSITIVE = [] include Aws::Structure end |