Class: Aws::CostExplorer::Types::ListCostAllocationTagsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::ListCostAllocationTagsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of objects that are returned for this request.
-
#next_token ⇒ String
The token to retrieve the next set of results.
-
#status ⇒ String
The status of cost allocation tag keys that are returned for this request.
-
#tag_keys ⇒ Array<String>
The list of cost allocation tag keys that are returned for this request.
-
#type ⇒ String
The type of
CostAllocationTagobject that are returned for this request.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of objects that are returned for this request. By default, the request returns 100 results.
5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797 class ListCostAllocationTagsRequest < Struct.new( :status, :tag_keys, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.
5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797 class ListCostAllocationTagsRequest < Struct.new( :status, :tag_keys, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of cost allocation tag keys that are returned for this request.
5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797 class ListCostAllocationTagsRequest < Struct.new( :status, :tag_keys, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#tag_keys ⇒ Array<String>
The list of cost allocation tag keys that are returned for this request.
5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797 class ListCostAllocationTagsRequest < Struct.new( :status, :tag_keys, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of CostAllocationTag object that are returned for this request. The AWSGenerated type tags are tags that Amazon Web Services defines and applies to support Amazon Web Services resources for cost allocation purposes. The UserDefined type tags are tags that you define, create, and apply to resources.
5797 5798 5799 5800 5801 5802 5803 5804 5805 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 5797 class ListCostAllocationTagsRequest < Struct.new( :status, :tag_keys, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |