Class: Aws::CostExplorer::Types::SavingsPlansPurchaseRecommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::SavingsPlansPurchaseRecommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Contains your request parameters, Savings Plan Recommendations Summary, and Details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_scope ⇒ String
The account scope that you want your recommendations for.
-
#lookback_period_in_days ⇒ String
The lookback period in days that's used to generate the recommendation.
-
#payment_option ⇒ String
The payment option that's used to generate the recommendation.
-
#savings_plans_purchase_recommendation_details ⇒ Array<Types::SavingsPlansPurchaseRecommendationDetail>
Details for the Savings Plans that we recommend that you purchase to cover existing Savings Plans eligible workloads.
-
#savings_plans_purchase_recommendation_summary ⇒ Types::SavingsPlansPurchaseRecommendationSummary
Summary metrics for your Savings Plans Recommendations.
-
#savings_plans_type ⇒ String
The requested Savings Plans recommendation type.
-
#term_in_years ⇒ String
The Savings Plans recommendation term in years.
Instance Attribute Details
#account_scope ⇒ String
The account scope that you want your recommendations for. Amazon Web
Services calculates recommendations that include the management
account and member accounts if the value is set to PAYER. If the
value is LINKED, recommendations are calculated for individual
member accounts only.
7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579 class SavingsPlansPurchaseRecommendation < Struct.new( :account_scope, :savings_plans_type, :term_in_years, :payment_option, :lookback_period_in_days, :savings_plans_purchase_recommendation_details, :savings_plans_purchase_recommendation_summary) SENSITIVE = [] include Aws::Structure end |
#lookback_period_in_days ⇒ String
The lookback period in days that's used to generate the recommendation.
7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579 class SavingsPlansPurchaseRecommendation < Struct.new( :account_scope, :savings_plans_type, :term_in_years, :payment_option, :lookback_period_in_days, :savings_plans_purchase_recommendation_details, :savings_plans_purchase_recommendation_summary) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option that's used to generate the recommendation.
7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579 class SavingsPlansPurchaseRecommendation < Struct.new( :account_scope, :savings_plans_type, :term_in_years, :payment_option, :lookback_period_in_days, :savings_plans_purchase_recommendation_details, :savings_plans_purchase_recommendation_summary) SENSITIVE = [] include Aws::Structure end |
#savings_plans_purchase_recommendation_details ⇒ Array<Types::SavingsPlansPurchaseRecommendationDetail>
Details for the Savings Plans that we recommend that you purchase to cover existing Savings Plans eligible workloads.
7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579 class SavingsPlansPurchaseRecommendation < Struct.new( :account_scope, :savings_plans_type, :term_in_years, :payment_option, :lookback_period_in_days, :savings_plans_purchase_recommendation_details, :savings_plans_purchase_recommendation_summary) SENSITIVE = [] include Aws::Structure end |
#savings_plans_purchase_recommendation_summary ⇒ Types::SavingsPlansPurchaseRecommendationSummary
Summary metrics for your Savings Plans Recommendations.
7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579 class SavingsPlansPurchaseRecommendation < Struct.new( :account_scope, :savings_plans_type, :term_in_years, :payment_option, :lookback_period_in_days, :savings_plans_purchase_recommendation_details, :savings_plans_purchase_recommendation_summary) SENSITIVE = [] include Aws::Structure end |
#savings_plans_type ⇒ String
The requested Savings Plans recommendation type.
7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579 class SavingsPlansPurchaseRecommendation < Struct.new( :account_scope, :savings_plans_type, :term_in_years, :payment_option, :lookback_period_in_days, :savings_plans_purchase_recommendation_details, :savings_plans_purchase_recommendation_summary) SENSITIVE = [] include Aws::Structure end |
#term_in_years ⇒ String
The Savings Plans recommendation term in years. It's used to generate the recommendation.
7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7579 class SavingsPlansPurchaseRecommendation < Struct.new( :account_scope, :savings_plans_type, :term_in_years, :payment_option, :lookback_period_in_days, :savings_plans_purchase_recommendation_details, :savings_plans_purchase_recommendation_summary) SENSITIVE = [] include Aws::Structure end |