Class: Aws::CostExplorer::Types::SavingsPlansUtilizationAggregates
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::SavingsPlansUtilizationAggregates
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
The aggregated utilization metrics for your Savings Plans usage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amortized_commitment ⇒ Types::SavingsPlansAmortizedCommitment
The total amortized commitment for a Savings Plans.
-
#savings ⇒ Types::SavingsPlansSavings
The amount that’s saved by using existing Savings Plans.
-
#utilization ⇒ Types::SavingsPlansUtilization
A ratio of your effectiveness of using existing Savings Plans to apply to workloads that are Savings Plans eligible.
Instance Attribute Details
#amortized_commitment ⇒ Types::SavingsPlansAmortizedCommitment
The total amortized commitment for a Savings Plans. This includes the sum of the upfront and recurring Savings Plans fees.
7871 7872 7873 7874 7875 7876 7877 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7871 class SavingsPlansUtilizationAggregates < Struct.new( :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#savings ⇒ Types::SavingsPlansSavings
The amount that’s saved by using existing Savings Plans. Savings returns both net savings from Savings Plans and also the onDemandCostEquivalent of the Savings Plans when considering the utilization rate.
7871 7872 7873 7874 7875 7876 7877 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7871 class SavingsPlansUtilizationAggregates < Struct.new( :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#utilization ⇒ Types::SavingsPlansUtilization
A ratio of your effectiveness of using existing Savings Plans to apply to workloads that are Savings Plans eligible.
7871 7872 7873 7874 7875 7876 7877 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7871 class SavingsPlansUtilizationAggregates < Struct.new( :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |