Class: Aws::CostExplorer::Types::SavingsPlansUtilizationByTime
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::SavingsPlansUtilizationByTime
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
The amount of Savings Plans utilization (in hours).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amortized_commitment ⇒ Types::SavingsPlansAmortizedCommitment
The total amortized commitment for a Savings Plans.
-
#savings ⇒ Types::SavingsPlansSavings
The amount that’s saved by using existing Savings Plans.
-
#time_period ⇒ Types::DateInterval
The time period of the request.
-
#utilization ⇒ Types::SavingsPlansUtilization
A ratio of your effectiveness of using existing Savings Plans to apply to workloads that are Savings Plans eligible.
Instance Attribute Details
#amortized_commitment ⇒ Types::SavingsPlansAmortizedCommitment
The total amortized commitment for a Savings Plans. This includes the sum of the upfront and recurring Savings Plans fees.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7904 class SavingsPlansUtilizationByTime < Struct.new( :time_period, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#savings ⇒ Types::SavingsPlansSavings
The amount that’s saved by using existing Savings Plans. Savings returns both net savings from Savings Plans and also the onDemandCostEquivalent of the Savings Plans when considering the utilization rate.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7904 class SavingsPlansUtilizationByTime < Struct.new( :time_period, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::DateInterval
The time period of the request.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7904 class SavingsPlansUtilizationByTime < Struct.new( :time_period, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |
#utilization ⇒ Types::SavingsPlansUtilization
A ratio of your effectiveness of using existing Savings Plans to apply to workloads that are Savings Plans eligible.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 7904 class SavingsPlansUtilizationByTime < Struct.new( :time_period, :utilization, :savings, :amortized_commitment) SENSITIVE = [] include Aws::Structure end |