Class: Aws::CostExplorer::Types::TargetInstance

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-costexplorer/types.rb

Overview

Details on recommended instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currency_codeString

The currency code that Amazon Web Services used to calculate the costs for this instance.



8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
# File 'lib/aws-sdk-costexplorer/types.rb', line 8239

class TargetInstance < Struct.new(
  :estimated_monthly_cost,
  :estimated_monthly_savings,
  :currency_code,
  :default_target_instance,
  :resource_details,
  :expected_resource_utilization,
  :platform_differences)
  SENSITIVE = []
  include Aws::Structure
end

#default_target_instanceBoolean

Determines whether this recommendation is the defaulted Amazon Web Services recommendation.



8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
# File 'lib/aws-sdk-costexplorer/types.rb', line 8239

class TargetInstance < Struct.new(
  :estimated_monthly_cost,
  :estimated_monthly_savings,
  :currency_code,
  :default_target_instance,
  :resource_details,
  :expected_resource_utilization,
  :platform_differences)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_monthly_costString

The expected cost to operate this instance type on a monthly basis.



8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
# File 'lib/aws-sdk-costexplorer/types.rb', line 8239

class TargetInstance < Struct.new(
  :estimated_monthly_cost,
  :estimated_monthly_savings,
  :currency_code,
  :default_target_instance,
  :resource_details,
  :expected_resource_utilization,
  :platform_differences)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_monthly_savingsString

The estimated savings that result from modification, on a monthly basis.



8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
# File 'lib/aws-sdk-costexplorer/types.rb', line 8239

class TargetInstance < Struct.new(
  :estimated_monthly_cost,
  :estimated_monthly_savings,
  :currency_code,
  :default_target_instance,
  :resource_details,
  :expected_resource_utilization,
  :platform_differences)
  SENSITIVE = []
  include Aws::Structure
end

#expected_resource_utilizationTypes::ResourceUtilization

The expected utilization metrics for target instance type.



8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
# File 'lib/aws-sdk-costexplorer/types.rb', line 8239

class TargetInstance < Struct.new(
  :estimated_monthly_cost,
  :estimated_monthly_savings,
  :currency_code,
  :default_target_instance,
  :resource_details,
  :expected_resource_utilization,
  :platform_differences)
  SENSITIVE = []
  include Aws::Structure
end

#platform_differencesArray<String>

Explains the actions that you might need to take to successfully migrate your workloads from the current instance type to the recommended instance type.



8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
# File 'lib/aws-sdk-costexplorer/types.rb', line 8239

class TargetInstance < Struct.new(
  :estimated_monthly_cost,
  :estimated_monthly_savings,
  :currency_code,
  :default_target_instance,
  :resource_details,
  :expected_resource_utilization,
  :platform_differences)
  SENSITIVE = []
  include Aws::Structure
end

#resource_detailsTypes::ResourceDetails

Details on the target instance type.



8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
# File 'lib/aws-sdk-costexplorer/types.rb', line 8239

class TargetInstance < Struct.new(
  :estimated_monthly_cost,
  :estimated_monthly_savings,
  :currency_code,
  :default_target_instance,
  :resource_details,
  :expected_resource_utilization,
  :platform_differences)
  SENSITIVE = []
  include Aws::Structure
end