Class: Aws::CostExplorer::Types::TargetInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::CostExplorer::Types::TargetInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-costexplorer/types.rb
Overview
Details on recommended instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code that Amazon Web Services used to calculate the costs for this instance.
-
#default_target_instance ⇒ Boolean
Determines whether this recommendation is the defaulted Amazon Web Services recommendation.
-
#estimated_monthly_cost ⇒ String
The expected cost to operate this instance type on a monthly basis.
-
#estimated_monthly_savings ⇒ String
The estimated savings that result from modification, on a monthly basis.
-
#expected_resource_utilization ⇒ Types::ResourceUtilization
The expected utilization metrics for target instance type.
-
#platform_differences ⇒ Array<String>
Explains the actions that you might need to take to successfully migrate your workloads from the current instance type to the recommended instance type.
-
#resource_details ⇒ Types::ResourceDetails
Details on the target instance type.
Instance Attribute Details
#currency_code ⇒ String
The currency code that Amazon Web Services used to calculate the costs for this instance.
8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8248 class TargetInstance < Struct.new( :estimated_monthly_cost, :estimated_monthly_savings, :currency_code, :default_target_instance, :resource_details, :expected_resource_utilization, :platform_differences) SENSITIVE = [] include Aws::Structure end |
#default_target_instance ⇒ Boolean
Determines whether this recommendation is the defaulted Amazon Web Services recommendation.
8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8248 class TargetInstance < Struct.new( :estimated_monthly_cost, :estimated_monthly_savings, :currency_code, :default_target_instance, :resource_details, :expected_resource_utilization, :platform_differences) SENSITIVE = [] include Aws::Structure end |
#estimated_monthly_cost ⇒ String
The expected cost to operate this instance type on a monthly basis.
8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8248 class TargetInstance < Struct.new( :estimated_monthly_cost, :estimated_monthly_savings, :currency_code, :default_target_instance, :resource_details, :expected_resource_utilization, :platform_differences) SENSITIVE = [] include Aws::Structure end |
#estimated_monthly_savings ⇒ String
The estimated savings that result from modification, on a monthly basis.
8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8248 class TargetInstance < Struct.new( :estimated_monthly_cost, :estimated_monthly_savings, :currency_code, :default_target_instance, :resource_details, :expected_resource_utilization, :platform_differences) SENSITIVE = [] include Aws::Structure end |
#expected_resource_utilization ⇒ Types::ResourceUtilization
The expected utilization metrics for target instance type.
8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8248 class TargetInstance < Struct.new( :estimated_monthly_cost, :estimated_monthly_savings, :currency_code, :default_target_instance, :resource_details, :expected_resource_utilization, :platform_differences) SENSITIVE = [] include Aws::Structure end |
#platform_differences ⇒ Array<String>
Explains the actions that you might need to take to successfully migrate your workloads from the current instance type to the recommended instance type.
8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8248 class TargetInstance < Struct.new( :estimated_monthly_cost, :estimated_monthly_savings, :currency_code, :default_target_instance, :resource_details, :expected_resource_utilization, :platform_differences) SENSITIVE = [] include Aws::Structure end |
#resource_details ⇒ Types::ResourceDetails
Details on the target instance type.
8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 |
# File 'lib/aws-sdk-costexplorer/types.rb', line 8248 class TargetInstance < Struct.new( :estimated_monthly_cost, :estimated_monthly_savings, :currency_code, :default_target_instance, :resource_details, :expected_resource_utilization, :platform_differences) SENSITIVE = [] include Aws::Structure end |